%global domain          github.com
%global org             kata-containers
%global repo            osbuilder
%global download        %{domain}/%{org}/%{repo}
%global importname      %{download}
%global katadir         %{_datadir}/kata-containers
%global katalibexecdir  %{_libexecdir}/kata-containers

# Not building any debug information in this package (all scripts)
%global debug_package   %{nil}

Name:      kata-%{repo}
Version:   1.8.0
Release:   1%{?dist}
License:   ASL 2.0
Summary:   Guest OS building scripts for Kata containers
URL:       https://%{download}
Source0:   https://%{download}/archive/%{version}/%{name}-%{version}.tar.gz
BuildRequires: golang
Requires(post): golang
Requires(post): qemu-img
# F31: % {?go_compiler:compiler(go-compiler)}% {!?go_compiler:golang}
# F31: Requires(post): go-srpm-macros

%description
Tools to create a guest OS disk image for Kata containers

The Kata Containers runtime creates a virtual machine (VM) to isolate
a set of container workloads. The VM requires a guest kernel and a
guest operating system ("guest OS") to boot and create containers
inside the guest environment. This package contains the tools to create
guest OS images.

%prep
%autosetup -n %{repo}-%{version}

%build

%install
install -dp %{buildroot}%{katadir}
install -dp %{buildroot}%{katalibexecdir}/{image-builder,initrd-builder,rootfs-builder,scripts}
install -p -m 755 rootfs-builder/rootfs.sh %{buildroot}%{katalibexecdir}/rootfs-builder/kata-rootfs_builder
install -p -m 755 image-builder/image_builder.sh %{buildroot}%{katalibexecdir}/image-builder/kata-image_builder
install -p -m 755 initrd-builder/initrd_builder.sh %{buildroot}%{katalibexecdir}/initrd-builder/kata-initrd_builder
install -p -m 755 scripts/lib.sh %{buildroot}%{katalibexecdir}/scripts/lib.sh

for distro in alpine centos clearlinux euleros fedora debian suse ubuntu
do
    install -dp %{buildroot}%{katalibexecdir}/rootfs-builder/$distro
    install -p -m 644 rootfs-builder/$distro/config.sh %{buildroot}%{katalibexecdir}/rootfs-builder/$distro
done

%post
echo "Creating Fedora image..."
GOPATH=%{gopath} OS_VERSION=%{?fedora} %{katalibexecdir}/rootfs-builder/kata-rootfs_builder fedora
GOPATH=%{gopath} %{katalibexecdir}/image-builder/kata-image_builder %{katalibexecdir}/rootfs-builder/rootfs-Fedora
GOPATH=%{gopath} %{katalibexecdir}/initrd-builder/kata-initrd_builder %{katalibexecdir}/rootfs-builder/rootfs-Fedora
mv /kata-* %{katadir}
rm -rf %{katalibexecdir}/rootfs-builder/rootfs-Fedora

%files
%license LICENSE
%doc CODE_OF_CONDUCT.md CONTRIBUTING.md README.md
%dir %{katadir}
%dir %{katalibexecdir}
%dir %{katalibexecdir}/rootfs-builder
%dir %{katalibexecdir}/image-builder
%dir %{katalibexecdir}/initrd-builder
%dir %{katalibexecdir}/scripts
%{katalibexecdir}/rootfs-builder/*/config.sh
%{katalibexecdir}/image-builder/kata-image_builder
%{katalibexecdir}/initrd-builder/kata-initrd_builder
%{katalibexecdir}/rootfs-builder/kata-rootfs_builder
%{katalibexecdir}/scripts/lib.sh

%changelog
* Tue Jul 30 2019 Christophe de Dinechin <dinechin@redhat.com> - 1.8.0-1
- Update to 1.8.0 release

* Fri Jul 12 2019 Christophe de Dinechin <dinechin@redhat.com> - 1.7.3-1
- Update to 1.7.3 release, cleanup spec file

* Mon Nov 26 2018 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.4.0-4.git39e6aa4
- update summary and description

* Mon Nov 26 2018 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.4.0-3.git39e6aa4
- install license and docs

* Fri Nov 23 2018 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.4.0-2.git39e6aa4
- use qemu-img

* Fri Nov 23 2018 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.4.0-1.git39e6aa4
- bump to v1.4.0
- built commit 39e6aa4

* Sun Nov 11 2018 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.0.0-1.git37d1824
- bump to 1.3.1
- built commit 37d1824

* Thu Jun 28 2018 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.0.0-1.gitac0c290
- initial build
